@@ -27,3 +27,10 @@ class ColossalSet224x224(H5Dataset):
                    transform=transform, 
                    transform_target=transform_target
                   )
+
+    @staticmethod
+    def normalization_values():
+        # Calculated on the 'train' set
+        mean = [0.7157, 0.4982, 0.6758]
+        std = [0.1782, 0.2027, 0.1604]
+        return mean, std
