@@ -68,6 +68,13 @@ class ICPR96x96Balanced(H5Dataset):
     def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
         return cls('/data/ldap/histopathologic/processed/icpr_mitosis/', sub_set, transform, transform_target)
 
+    @staticmethod
+    def normalization_values():
+        # Calculated on the 'train' set
+        mean = [0.7802, 0.4520, 0.6357]
+        std = [0.1533, 0.2005, 0.1622]
+        return mean, std
+
 
 class ICPR96x96Unbalanced(H5Dataset):
     """ 
@@ -88,3 +95,10 @@ class ICPR96x96Unbalanced(H5Dataset):
     @classmethod
     def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
         return cls('/data/ldap/histopathologic/processed/icpr_mitosis/', sub_set, transform, transform_target)
+
+    @staticmethod
+    def normalization_values():
+        # Calculated on the 'train' set
+        mean = [0.7815, 0.4431, 0.6381]
+        std = [0.1396, 0.1893, 0.1483]
+        return mean, std
