@@ -38,7 +38,7 @@ class WideBasicBlock(nn.Module):
         self,
         in_planes,
         planes,
-        dropout_rate,
+        dropout_rate=0.0,
         stride=1
     ):
         super(WideBasicBlock, self).__init__()
@@ -71,7 +71,7 @@ class WideResNet(nn.Module):
         self,
         depth,
         widen_factor,
-        dropout_rate=0.3
+        dropout_rate=0.0
     ):
         super(WideResNet, self).__init__()
 
